@@ -1,6 +1,8 @@
 """pyvelop CLI."""
 
 # region #-- imports --#
+from __future__ import annotations
+
 import json
 import logging
 import re
@@ -293,6 +295,22 @@ async def mesh_details(
                                 speedtest_results=mesh_obj.latest_speedtest_result
                             ),
                         ),
+                        ("dhcp_enabled", "DHCP Enabled"),
+                        (
+                            "dhcp_reservations",
+                            "DHCP Reservations",
+                            prefix
+                            + prefix.join(
+                                [
+                                    f"{reservation.get('description')},"
+                                    f"{reservation.get('mac_address')},"
+                                    f"{reservation.get('ip_address')}"
+                                    for reservation in mesh_obj.dhcp_reservations
+                                ]
+                            )
+                            if len(mesh_obj.dhcp_reservations)
+                            else "None",
+                        ),
                         ("parental_control_enabled", "Parental Control Enabled"),
                         ("wps_state", "WPS Enabled"),
                         ("is_channel_scan_running", "Channel Scan Running"),
@@ -300,6 +318,15 @@ async def mesh_details(
                         ("homekit_paired", "HomeKit Integration Paired"),
                         ("client_steering_enabled", "Client Steering Enabled"),
                         ("node_steering_enabled", "Node Steering Enabled"),
+                        ("upnp_enabled", "UPnP Enabled"),
+                        ("upnp_allow_change_settings", "UPnP Allow Change Settings"),
+                        ("upnp_allow_disable_internet", "UPnP Allow Disable Internet"),
+                        ("sip_enabled", "SIP Enabled"),
+                        (
+                            "express_forwarding_supported",
+                            "Express Forwarding Supported",
+                        ),
+                        ("express_forwarding_enabled", "Express Forwarding Enabled"),
                         (
                             "mac_filtering",
                             "MAC Filtering",
@@ -641,6 +668,8 @@ def _connected_details(adapters: List[Dict]) -> str:
             ("mac", "MAC"),
             ("ip", "IPv4"),
             ("ipv6", "IPv6"),
+            ("reservation", "Reservation"),
+            ("reservation_description", "Reserved Name"),
             ("guest_network", "Guest"),
             (
                 "signal_strength",
