@@ -1,5 +1,8 @@
 """Representation of a mesh device."""
 
+# region #-- imports --#
+from __future__ import annotations
+
 import base64
 import datetime
 from enum import IntEnum
@@ -7,6 +10,8 @@ from typing import Any, Dict, List, final
 
 from .base import MeshDevice
 
+# endregion
+
 
 class ParentalControl:
     """Class to manage parental control schedules."""
@@ -47,7 +52,7 @@ class ParentalControl:
 
         return ret
 
-    def _human_readable(self, schedule: Dict[str, str]) -> Dict[str, str]:
+    def _human_readable(self, schedule: Dict[str, str]) -> Dict[str, List[str]]:
         """Make the given schedule human readable."""
         ret = {}
         for day, sched in schedule.items():
@@ -125,7 +130,7 @@ class ParentalControl:
         return self._rule.get("description", "default description")
 
     @property
-    def human_readable_cached_schedule(self) -> Dict[str, str]:
+    def human_readable_cached_schedule(self) -> Dict[str, List[str]]:
         """Return the cached schedule in human readable form."""
         if self.cached_schedule is not None:
             return self._human_readable(self.cached_schedule)
@@ -133,7 +138,7 @@ class ParentalControl:
         return None
 
     @property
-    def human_readable_schedule(self) -> Dict[str, str]:
+    def human_readable_schedule(self) -> Dict[str, List[str]]:
         """Return the schedule in human readable form."""
         return self._human_readable(self.schedule)
 
@@ -187,7 +192,6 @@ class Device(MeshDevice):
         :param kwargs: keyword arguments
         """
         super().__init__(**kwargs)
-        self.__parent_name: str | None = None
 
     @property
     def description(self) -> str | None:
@@ -247,7 +251,7 @@ class Device(MeshDevice):
     @property
     def parent_name(self) -> str | None:
         """Name of the node the device is connected to."""
-        return self.__parent_name
+        return self._attribs.get("parent_name")
 
     @property
     def serial(self) -> str | None:
