@@ -49,14 +49,17 @@ class Actions(str, Enum):
 
     CHECK_PASSWORD: str = f"{ROOT}/core/CheckAdminPassword"
     DELETE_DEVICE: str = f"{ROOT}/devicelist/DeleteDevice"
+    GET_ALG_SETTINGS: str = f"{ROOT}/firewall/GetALGSettings"
     GET_BACKHAUL: str = f"{ROOT}/nodes/diagnostics/GetBackhaulInfo"
     GET_CHANNEL_SCAN_STATUS: str = f"{ROOT}/nodes/setup/GetSelectedChannels"
     GET_DEVICES: str = f"{ROOT}/devicelist/GetDevices3"
+    GET_EXPRESS_FORWARDING: str = f"{ROOT}/router/GetExpressForwardingSettings"
     GET_FIRMWARE_UPDATE_SETTINGS: str = (
         f"{ROOT}/firmwareupdate/GetFirmwareUpdateSettings"
     )
     GET_GUEST_NETWORK_INFO: str = f"{ROOT}/guestnetwork/GetGuestRadioSettings2"
     GET_HOMEKIT_SETTINGS: str = f"{ROOT}/homekit/GetHomeKitSettings"
+    GET_LAN_SETTINGS: str = f"{ROOT}/router/GetLANSettings"
     GET_MAC_FILTERING_SETTINGS: str = f"{ROOT}/macfilter/GetMACFilterSettings"
     GET_NETWORK_CONNECTIONS: str = (
         f"{ROOT}/nodes/networkconnections/GetNodesWirelessNetworkConnections"
@@ -75,6 +78,7 @@ class Actions(str, Enum):
         f"{ROOT}/nodes/firmwareupdate/GetFirmwareUpdateStatus"
     )
     GET_UPDATE_SETTINGS: str = f"{ROOT}/firmwareupdate/GetFirmwareUpdateSettings"
+    GET_UPNP_SETTINGS: str = f"{ROOT}/routerupnp/GetUPnPSettings"
     GET_WAN_INFO: str = f"{ROOT}/router/GetWANStatus3"
     GET_WPS_SERVER_SETTINGS: str = f"{ROOT}/wirelessap/GetWPSServerSettings"
     REBOOT: str = f"{ROOT}/core/Reboot"
@@ -88,6 +92,16 @@ class Actions(str, Enum):
     TRANSACTION: str = f"{ROOT}/core/Transaction"
     UPDATE_FIRMWARE: str = f"{ROOT}/nodes/firmwareupdate/UpdateFirmwareNow"
 
+    @classmethod
+    def is_unsafe(cls, action: str) -> bool:
+        """Return if the action is unsafe."""
+        return action in {
+            "GET_HOMEKIT_SETTINGS",
+            "GET_NETWORK_CONNECTIONS",
+            "GET_STORAGE_SMB_SERVER",
+            "GET_STORAGE_PARTITIONS",
+        }
+
 
 @dataclass
 class Defaults:
@@ -97,7 +111,7 @@ class Defaults:
     payloads[Actions.GET_SPEEDTEST_RESULTS] = {
         "healthCheckModule": "SpeedTest",
         "includeModuleResults": True,
-        "lastNumberOfResults": 1,
+        "lastNumberOfResults": 10,
     }
 
 
